==> ejc-bfyjerp-api-3.0.0-20250212.033201-128-sources.jar: com/ejianc/business/bid/vo/MonthFeeCommissionVO.java <==
package com.ejianc.business.bid.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;

/**
 * @author CJ
 * @Description:
 * @date 2024/11/11 20:09
 */
public class MonthFeeCommissionVO extends BaseVO {
    private static final long serialVersionUID = -702930283059271568L;

    private String deptName;//人员部门名称
    private String postName;//人员岗位名称
    private String employeeName;//人员名称
    private Long employeeId; //人员Id
    private Long orgId; //人员所属组织Id
    private String orgCode;  //人员所属组织编码
    private String orgName; //人员所属组织名称
    private String employeeCode;//人员编码
    private BigDecimal registrationMny;//报名提成
    private BigDecimal fileMny;//资料提成
    private BigDecimal authMny;//授权提成
    private BigDecimal budgetMny;//预算提成
    private BigDecimal bidDocMny;//标书提成
    private BigDecimal totalMny; //总金额
    private String year;//年份
    private String month;//月度

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getYear() {
        return year;
    }

    public void setYear(String year) {
        this.year = year;
    }

    public String getMonth() {
        return month;
    }

    public void setMonth(String month) {
        this.month = month;
    }

    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }

    public String getPostName() {
        return postName;
    }

    public void setPostName(String postName) {
        this.postName = postName;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }

    public BigDecimal getRegistrationMny() {
        return registrationMny;
    }

    public void setRegistrationMny(BigDecimal registrationMny) {
        this.registrationMny = registrationMny;
    }

    public BigDecimal getFileMny() {
        return fileMny;
    }

    public void setFileMny(BigDecimal fileMny) {
        this.fileMny = fileMny;
    }

    public BigDecimal getAuthMny() {
        return authMny;
    }

    public void setAuthMny(BigDecimal authMny) {
        this.authMny = authMny;
    }

    public BigDecimal getBudgetMny() {
        return budgetMny;
    }

    public void setBudgetMny(BigDecimal budgetMny) {
        this.budgetMny = budgetMny;
    }

    public BigDecimal getBidDocMny() {
        return bidDocMny;
    }

    public void setBidDocMny(BigDecimal bidDocMny) {
        this.bidDocMny = bidDocMny;
    }

    public BigDecimal getTotalMny() {
        return totalMny;
    }

    public void setTotalMny(BigDecimal totalMny) {
        this.totalMny = totalMny;
    }
}

==> ejc-bfyjerp-api-3.0.0-20250717.090635-244-sources.jar: com/ejianc/business/bid/vo/MonthFeeCommissionVO.java <==
package com.ejianc.business.bid.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;

/**
 * @author CJ
 * @Description:
 * @date 2024/11/11 20:09
 */
public class MonthFeeCommissionVO extends BaseVO {
    private static final long serialVersionUID = -702930283059271568L;

    private String deptName;//人员部门名称
    private String postName;//人员岗位名称
    private String employeeName;//人员名称
    private Long employeeId; //人员Id
    private Long orgId; //人员所属组织Id
    private String orgCode;  //人员所属组织编码
    private String orgName; //人员所属组织名称
    private String employeeCode;//人员编码
    private BigDecimal registrationMny;//报名提成
    private BigDecimal fileMny;//资料提成
    private BigDecimal authMny;//授权提成
    private BigDecimal budgetMny;//预算提成
    private BigDecimal bidDocMny;//标书提成
    private BigDecimal totalMny; //总金额
    private String year;//年份
    private String month;//月度
    private String opprIds;//来源商机ids(,分割)
    @JsonFormat(pattern = "yyyy-MM", timezone = "GMT+8")
    private Date billDate; // 生成日期

    public Date getBillDate() {
        return billDate;
    }

    public void setBillDate(Date billDate) {
        this.billDate = billDate;
    }
    public String getOpprIds() {
        return opprIds;
    }

    public void setOpprIds(String opprIds) {
        this.opprIds = opprIds;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getYear() {
        return year;
    }

    public void setYear(String year) {
        this.year = year;
    }

    public String getMonth() {
        return month;
    }

    public void setMonth(String month) {
        this.month = month;
    }

    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }

    public String getPostName() {
        return postName;
    }

    public void setPostName(String postName) {
        this.postName = postName;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }

    public BigDecimal getRegistrationMny() {
        return registrationMny;
    }

    public void setRegistrationMny(BigDecimal registrationMny) {
        this.registrationMny = registrationMny;
    }

    public BigDecimal getFileMny() {
        return fileMny;
    }

    public void setFileMny(BigDecimal fileMny) {
        this.fileMny = fileMny;
    }

    public BigDecimal getAuthMny() {
        return authMny;
    }

    public void setAuthMny(BigDecimal authMny) {
        this.authMny = authMny;
    }

    public BigDecimal getBudgetMny() {
        return budgetMny;
    }

    public void setBudgetMny(BigDecimal budgetMny) {
        this.budgetMny = budgetMny;
    }

    public BigDecimal getBidDocMny() {
        return bidDocMny;
    }

    public void setBidDocMny(BigDecimal bidDocMny) {
        this.bidDocMny = bidDocMny;
    }

    public BigDecimal getTotalMny() {
        return totalMny;
    }

    public void setTotalMny(BigDecimal totalMny) {
        this.totalMny = totalMny;
    }
}
